@@ -142,7 +142,7 @@ E.g.
 
 sub process {
     my ($self, %opts) = @_;
-    my (@pieces, @splat, $splithtml);
+    my (@pieces, @splat);
     my $split = $opts{split};
     my $imagere = $self->image_re;
     $self->reset_toc_stack;
@@ -323,6 +323,11 @@ Main routine to transform a string to the given format
 
 =cut
 
+sub _get_unique_counter {
+    my $self = shift;
+    ++$self->{_unique_counter};
+}
+
 sub manage_regular {
     my ($self, $el, %opts) = @_;
     my $string;
@@ -338,6 +343,30 @@ sub manage_regular {
     }
     return "" unless defined $string;
     my $linkre = $self->link_re;
+
+    # remove the verbatim pieces
+    my @verbatims;
+    my $rand = sprintf('%u', rand(1000000000)) . 'b1fc670b2e799b90b2f65124021de691' . $self->_get_unique_counter;
+    # print "$string\n$rand\n\n";
+    my $startm = "\x{f0001}${rand}\x{f0002}";
+    my $stopm  = "\x{f0003}${rand}\x{f0004}";
+    my $save_verb = sub {
+        my $string = shift;
+        push @verbatims, $string;
+        return $startm . $#verbatims . $stopm;
+    };
+    my $restored = 0;
+    my $restore_verb = sub {
+        my $num = shift;
+        my $string = $verbatims[$num];
+        $restored++;
+        # print "Called restore_verb for $num\n";
+        die "Pulled too much when restoring verb" unless defined $string;
+        return $self->safe($string);
+    };
+
+    $string =~ s/<verbatim>(.+?)<\/verbatim>/$save_verb->($1)/gsxe;
+
     # split at [[ ]] to avoid the mess
     my @pieces = split /($linkre)/, $string;
     my @out;
@@ -367,8 +396,13 @@ sub manage_regular {
         if ($recurse) {
             $l = $self->inline_footnotes($l);
         }
+        # restore the verbatim pieces
+        $l =~ s/\Q$startm\E([0-9]+)\Q$stopm\E/$restore_verb->($1)/gsxe;
         push @out, $l;
     }
+    die "Failed to restore chunks" if $restored != @verbatims;
+    undef $save_verb;
+    undef $restore_verb;
     return join("", @out);
 }
 
